/* Application Explorer - a general-purpose application cataloger/indexer
 * Copyright (C) 2006  Aliasgar Lokhandwala <d7@freepgs.com> 
 * http://appexp.sourceforge.net/
 *
 * ComponentLogger.java: The class that helps in logging messages 
 * 	to any swing component
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the 
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package app.appexplorer.log;

import java.util.logging.*;
import java.util.logging.Handler;
import java.util.logging.LogRecord;

/**
 * Allows a UI component to be used for logging. This is a simple log handler
 * that can be attached to a UI component that is capable of logging messages
 * (like a JTextArea).
 * 
 * @author ali
 * @version 2
 */
public class ComponentLogger extends Handler {

    /**
     * The attached UI component used for logging.
     */
    private ILoggerComponent m_Component = null;

    /**
     * Create a ComponentLogger attached to the supplied UI component.
     * 
     * @param comp -
     *            A UI component capable of logging messages. Should not be
     *            null.
     */
    public ComponentLogger(ILoggerComponent comp) {
        m_Component = comp;
    }

    /**
     * Logs the given record by formatting it into a string and passing it to
     * the attached UI Component.
     * 
     * @see Handler#publish(java.util.logging.LogRecord)
     */
    public void publish(LogRecord lr) {
        Formatter f = getFormatter();
        String msg = lr.getMessage();

        //format the message if a formatter is attached
        if (f != null)
            msg = f.format(lr);

        //pass the message string to the logger
        m_Component.log(msg);
    }

    /**
     * Empty. Does Nothing.
     */
    public void flush() {
        //zzz...we have nothing to flush.
    }

    /**
     * Empty. Does Nothing.
     */
    public void close() throws SecurityException {
        //zzz...we have nothing to close.
    }
}